@@ -14,6 +14,7 @@
 #define ENABLE_DUMPDOCK 0
 
 #include "toplevel.h"
+#include <karchive_version.h>
 
 #include <stdlib.h> // for system()
 
@@ -47,11 +48,17 @@
 #include <KJobWidgets>
 #include <KEditToolBar>
 #include <KShortcutsDialog>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <KTipDialog>
+#endif
 #include <KMessageBox>
 #include <KSharedConfig>
 #include <KConfigGroup>
+#if KARCHIVE_VERSION < QT_VERSION_CHECK(5,85,0)
 #include <KFilterDev>
+#else
+#include <KCompressionDevice>
+#endif
 
 #if ENABLE_DUMPDOCK
 #include "dumpselection.h"
@@ -651,8 +658,13 @@ void TopLevel::createMiscActions()
 
     // cost types are dependent on loaded data, thus KSelectAction
     // is filled in setData()
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     connect( _saCost, SIGNAL(triggered(QString)),
              this, SLOT(eventTypeSelected(QString)));
+#else
+    connect( _saCost, &KSelectAction::textTriggered,
+             this, &TopLevel::eventTypeSelected);
+#endif
 
     _saCost2 = actionCollection()->add<KSelectAction>(QStringLiteral("view_cost_type2"));
     _saCost2->setText(i18n("Secondary Event Type"));
@@ -661,9 +673,13 @@ void TopLevel::createMiscActions()
     _saCost2->setToolTip( hint );
     _saCost2->setWhatsThis( hint );
     _saCost2->setItems(dummyItems);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     connect( _saCost2, SIGNAL(triggered(QString)),
              this, SLOT(eventType2Selected(QString)));
+#else
+    connect( _saCost2, &KSelectAction::textTriggered,
+             this, &TopLevel::eventTypeSelected);
+#endif
 
     saGroup = actionCollection()->add<KSelectAction>(QStringLiteral("view_group_type"));
     saGroup->setText(i18n("Grouping"));
@@ -681,8 +697,13 @@ void TopLevel::createMiscActions()
          << ProfileContext::i18nTypeName(ProfileContext::FunctionCycle);
 
     saGroup->setItems(args);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     connect( saGroup, SIGNAL(triggered(int)),
              this, SLOT(groupTypeSelected(int)));
+#else
+    connect( saGroup, &KSelectAction::triggered,
+             this, &TopLevel::groupTypeSelected);
+#endif
 
     _taSplit = actionCollection()->add<KToggleAction>(QStringLiteral("view_split"));
     _taSplit->setIcon(QIcon::fromTheme(QStringLiteral("view-split-left-right")));
@@ -870,7 +891,7 @@ void TopLevel::querySlot()
 
 void TopLevel::configureKeys()
 {
-    KShortcutsDialog::configure(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this);
+    KShortcutsDialog::showDialog(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this);
 }
 
 
@@ -1926,11 +1947,15 @@ void TopLevel::configChanged()
 }
 
 void TopLevel::slotShowTipOnStart() {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KTipDialog::showTip(this);
+#endif
 }
 
 void TopLevel::slotShowTip() {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KTipDialog::showTip( this, QString(), true );
+#endif
 }
 
 void TopLevel::dummySlot()
@@ -2039,8 +2064,13 @@ void TopLevel::forceTrace()
             SLOT(ccError(QProcess::ProcessError)));
     connect(_ccProcess, SIGNAL(finished(int,QProcess::ExitStatus)),
             SLOT(ccExit(int,QProcess::ExitStatus)));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     _ccProcess->start(QStringLiteral("callgrind_control -d %1").arg(pid),
                       QIODevice::ReadOnly);
+#else
+    _ccProcess->startCommand(QStringLiteral("callgrind_control -d %1").arg(pid),
+                      QIODevice::ReadOnly);
+#endif
 }
 
 void TopLevel::ccReadOutput()
@@ -2351,9 +2381,14 @@ bool TopLevel::openDataFile(const QString& file)
     QMimeDatabase dataBase;
     QString mimeType = dataBase.mimeTypeForFile(file, QMimeDatabase::MatchContent).name();
 
+#if KARCHIVE_VERSION >= QT_VERSION_CHECK(5,85,0)
+    auto compressionType = KCompressionDevice::compressionTypeForMimeType(mimeType);
+#else
+    auto compressionType = KFilterDev::compressionTypeForMimeType(mimeType);
+#endif
     KCompressionDevice* compressed;
     compressed = new KCompressionDevice(file,
-                                        KFilterDev::compressionTypeForMimeType(mimeType));
+                                        compressionType);
     if (compressed &&
         (compressed->compressionType() != KCompressionDevice::None)) {
         filesLoaded = d->load(compressed, file);
@@ -2369,4 +2404,4 @@ bool TopLevel::openDataFile(const QString& file)
     }
 }
 
-
+#include "moc_toplevel.cpp"
